@@ -71,6 +71,7 @@ Kimpanel::Kimpanel(QObject* parent, const QVariantList& args):
     connect(m_statusbar, SIGNAL(startIM()), this, SLOT(startIM()));
 
     connect(&m_inputPanelTimer, SIGNAL(timeout()), this, SLOT(updateInputPanel()));
+    connect(&m_statusBarTimer, SIGNAL(timeout()), this, SLOT(updateStatusBar()));
 }
 
 Kimpanel::~Kimpanel()
@@ -125,7 +126,6 @@ void Kimpanel::createConfigurationInterface(KConfigDialog* parent)
     QWidget *widget = new QWidget();
     m_generalUi.setupUi(widget);
     parent->addPage(widget, i18nc("General configuration page", "General"), icon());
-    m_generalUi.blurBehindCheckBox->setChecked(KimpanelSettings::self()->enableBackgroundBlur());
     m_generalUi.verticalListCheckBox->setChecked(KimpanelSettings::self()->verticalPreeditBar());
     m_generalUi.reverseCheckBox->setChecked(KimpanelSettings::self()->useReverse());
 
@@ -138,7 +138,6 @@ void Kimpanel::createConfigurationInterface(KConfigDialog* parent)
     connect(parent, SIGNAL(okClicked()), this, SLOT(configAccepted()));
 
     connect(this, SIGNAL(configFontChanged()), parent, SLOT(settingsModified()));
-    connect(m_generalUi.blurBehindCheckBox, SIGNAL(stateChanged(int)), parent, SLOT(settingsModified()));
     connect(m_generalUi.verticalListCheckBox, SIGNAL(stateChanged(int)), parent, SLOT(settingsModified()));
     connect(m_generalUi.reverseCheckBox, SIGNAL(stateChanged(int)), parent, SLOT(settingsModified()));
     connect(m_generalUi.selectIMButton, SIGNAL(clicked(bool)), parent, SLOT(settingsModified()));
@@ -158,7 +157,6 @@ void Kimpanel::configFont()
 
 void Kimpanel::configAccepted()
 {
-    KimpanelSettings::self()->setEnableBackgroundBlur(m_generalUi.blurBehindCheckBox->isChecked());
     KimpanelSettings::self()->setVerticalPreeditBar(m_generalUi.verticalListCheckBox->isChecked());
     KimpanelSettings::self()->setUseReverse(m_generalUi.reverseCheckBox->isChecked());
     KimpanelSettings::self()->setFont(m_font);
@@ -204,12 +202,10 @@ void Kimpanel::dataUpdated(const QString& source, const Plasma::DataEngine::Data
         if (!m_inputPanelTimer.isActive())
             m_inputPanelTimer.start();
     } else if (source == "statusbar") {
-        if (m_statusBarTimer.isActive()) {
-            m_statusBarTimer.disconnect(SIGNAL(timeout()));
-            m_statusBarTimer.stop();
-            connect(&m_statusBarTimer, SIGNAL(timeout()), this, SLOT(updateStatusBar()));
+        if (!m_statusBarTimer.isActive()) {
+            m_statusBarTimer.start();
         }
-        m_statusBarTimer.start();
+        updateStatusBar();
         if (data["Menu"].isValid()) {
             QMap< QString, QVariant > map = data["Menu"].toMap();
             quint64 timestamp = map["timestamp"].toULongLong();
