@@ -24,12 +24,13 @@
 #include <plasma/theme.h>
 
 AlphaNumKey::AlphaNumKey(QPoint relativePosition, QSize relativeSize, unsigned int keycode):
-        BoardKey(relativePosition, relativeSize, keycode){
-
+    BoardKey(relativePosition, relativeSize, keycode)
+{
     setLabel(0);
 }
 
-AlphaNumKey::~AlphaNumKey() {
+AlphaNumKey::~AlphaNumKey()
+{
 
 }
 
@@ -41,15 +42,16 @@ QString AlphaNumKey::label() const
 void AlphaNumKey::paint(QPainter *painter)
 {
     BoardKey::paint(painter);
-    paintLabel(painter);
-
+    if (!m_label.isEmpty()) {
+        paintLabel(painter);
+    }
 }
 
 void AlphaNumKey::paintLabel(QPainter *painter)
 {
     painter->save();
     int fontSize = qMin(size().width(), size().height()) / 2;
-    painter->setFont(QFont( Plasma::Theme::defaultTheme()->font(Plasma::Theme::DefaultFont).toString(), fontSize ));
+    painter->setFont(QFont(Plasma::Theme::defaultTheme()->font(Plasma::Theme::DefaultFont).toString(), fontSize));
     painter->setPen(Plasma::Theme::defaultTheme()->color(Plasma::Theme::ButtonTextColor));
     painter->drawText(rect(), Qt::AlignCenter, m_label);
     painter->restore();
@@ -57,8 +59,7 @@ void AlphaNumKey::paintLabel(QPainter *painter)
 
 void AlphaNumKey::setLabel(int level)
 {
-    //m_label = Helpers::mapToUnicode(Helpers::keycodeToKeysym(getKeycode(),level));
-    setLabel(Helpers::mapToUnicode(getKeysymbol(level)));
+    setLabel(Helpers::mapToUnicode(keysymbol(level)));
 }
 
 void AlphaNumKey::setLabel(const QString &label)
@@ -68,17 +69,13 @@ void AlphaNumKey::setLabel(const QString &label)
 
 void AlphaNumKey::switchKey(bool isLevel2, bool isAlternative, bool isLocked)
 {
-	if(isLocked){
-		isLevel2 = !isLevel2;
-	}
-	if(isLevel2){
-		isAlternative ? setLabel(4) : setLabel(1);
-	}
-	else{
-		setLabel(0);
-		/*isAlternative ?
-		setText(QChar(Helpers::mapToUnicode(Helpers::keycodeToKeysym(getKeycode(),0)))) :
-		setText(QChar(Helpers::mapToUnicode(Helpers::keycodeToKeysym(getKeycode(),0))));*/
+    if (isLocked) {
+        isLevel2 = !isLevel2;
+    }
+    if (isLevel2) {
+        isAlternative ? setLabel(4) : setLabel(1);
+    } else {
+        setLabel(0);
     }
 }
 
